@@ -4,4 +4,4 @@ Taxonomies
 
 Support for setting up and defining a taxonomy
 """
-from .taxonomy import Taxonomy
+from .taxonomy import Taxonomy, Taxon, RemoteTaxonomy
